"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const fs = require("fs");
const path = require("path");
const Koa = require("koa");
const Router = require("koa-router");
const serve = require("koa-static");
const axios_1 = require("axios");
const command_1 = require("@oclif/command");
function getAbsoluteFSPath() {
    return path.dirname(require.resolve('swagger-editor-dist'));
}
class SwaggerEditor extends command_1.Command {
    async run() {
        const { flags } = this.parse(SwaggerEditor);
        const { definition, port } = flags;
        const app = new Koa();
        const router = new Router();
        let document = null;
        if (definition) {
            if (definition.match('://')) {
                const { data } = await axios_1.default.get(definition);
                document = data;
            }
            else {
                document = fs.readFileSync(definition);
            }
        }
        const swaggerEditorRoot = getAbsoluteFSPath();
        if (document) {
            const indexHTML = fs.readFileSync(path.join(swaggerEditorRoot, 'index.html')).toString('utf8');
            router.get('/', (ctx) => {
                ctx.body = indexHTML.replace('window.editor = editor', `editor.specActions.updateSpec(\`${document}\`)\n\nwindow.editor = editor`);
            });
        }
        app.use(router.routes());
        app.use(serve(swaggerEditorRoot));
        const server = app.listen(port);
        process.on('disconnect', () => server.close());
        this.log(`Swagger Editor running at http://localhost:${port}`);
    }
}
SwaggerEditor.description = 'start a local Swagger UI instance';
SwaggerEditor.examples = ['$ openapi swagger-editor', '$ openapi swagger-editor -d ./openapi.yml'];
SwaggerEditor.flags = {
    help: command_1.flags.help({ char: 'h' }),
    port: command_1.flags.integer({ char: 'p', description: 'port', default: 9000 }),
    definition: command_1.flags.string({
        char: 'd',
        description: 'openapi definition file',
        required: true,
        helpValue: './openapi.yml',
    }),
};
SwaggerEditor.args = [];
exports.default = SwaggerEditor;
